package com.sample;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;

import org.drools.builder.DecisionTableConfiguration;
import org.drools.builder.DecisionTableInputType;
import org.drools.builder.KnowledgeBuilder;
import org.drools.builder.KnowledgeBuilderFactory;
import org.drools.builder.ResourceType;
import org.drools.compiler.DecisionTableFactory;
import org.drools.io.ResourceFactory;

/**
 * 
 * Empty column header in decision table throws NPE. Happens both with conditions and actions.
 * Happens both with XLS and CSV. Error can be seen in attached example. The example
 * contains error, but parser should not fail with NPE, but should respond with appropriate
 * error message understandable by user. 
 * 
 * @author jsvitak@redhat.com
 * @version BRMS 5.2.0 ER5
 *
 */
public class DecisionTableEmptyColumnHeader {

    public static void main(String [] args) throws FileNotFoundException {
        
        // csv tests NPE with ACTION, xls tests NPE in CONDITION, NPE is the same
        getKnowledgeBuilder("emptyAction.xls", DecisionTableInputType.XLS);
        //getKnowledgeBuilder("emptyAction.csv", DecisionTableInputType.CSV);
    }
    
    private static KnowledgeBuilder getKnowledgeBuilder(String fileName, DecisionTableInputType type) throws FileNotFoundException {
        DecisionTableConfiguration dtconf = KnowledgeBuilderFactory.newDecisionTableConfiguration();
        dtconf.setInputType(type);
        KnowledgeBuilder kbuilder = KnowledgeBuilderFactory.newKnowledgeBuilder();
        kbuilder.add(ResourceFactory.newFileResource(new File("test-resources", fileName)), ResourceType.DTABLE, dtconf);
        System.out.println(kbuilder.getErrors().toString());
        System.out.println(DecisionTableFactory.loadFromInputStream(new FileInputStream(new File("test-resources", fileName)), dtconf));
        return kbuilder;
    }
    
}
